<template>
  <ProDialog
    :title="innerForm.title"
    v-model="innerVisible"
    @close="onDialogClose"
    destroy-on-close
    draggable
  >
    <ProForm :rules="rules" :model="innerForm" ref="dialogForm" label-width="90px">
      <ProFormItemV2 label="行业类型:" prop="parentId" v-if="showWorkSearchType">
        <ProFormSelect
          v-model="innerForm.parentId"
          :value-enum="typeList"
          enum-value-key="id"
          enum-label-key="name"
        />
      </ProFormItemV2>
      <ProFormItemV2 label="名称:" prop="name">
        <ProFormText
          placeholder="请输入名称"
          v-model.trim="innerForm.name"
          :maxlength="15"
        ></ProFormText>
      </ProFormItemV2>
      <ProFormItemV2 label="排序:" prop="sort" required>
        <ProFormInputNumber
          v-model="innerForm.sort"
          :controls="false"
          :min="0"
          :max="999"
        ></ProFormInputNumber>
      </ProFormItemV2>
      <ProFormItemV2
        label="类别图标:"
        prop="src"
        :check-rules="[{ type: 'upload', required: false }]"
      >
        <ProFormImageUpload
          v-model:file-url="innerForm.src"
          :limitFileCount="1"
        ></ProFormImageUpload>
      </ProFormItemV2>
      <ProFormItemV2 label="状态:" prop="status" required>
        <el-radio-group v-model="innerForm.status">
          <el-radio-button :value="true">显示</el-radio-button>
          <el-radio-button :value="false">隐藏</el-radio-button>
        </el-radio-group>
      </ProFormItemV2>
    </ProForm>
    <template #footer>
      <span class="dialog-footer">
        <el-button @click="emit('onCancel')">取 消</el-button>
        <el-button type="primary" @click="handleConfirm">确 定</el-button>
      </span>
    </template>
  </ProDialog>
</template>

<script setup lang="ts">
import { FormRules, FormInstance } from 'element-plus';
import { SearchType } from '@/constants';
import {
  ProDialog,
  ProForm,
  ProFormItemV2,
  ProFormRadio,
  ProFormText,
  ProFormInputNumber,
  ProFormImageUpload,
  UploadUserFile,
  ProFormSelect,
} from '@bole-core/components';

defineOptions({
  name: 'AddOrEditSearchSetting',
});

type Props = {
  modelValue: boolean;
  form?: {
    title?: string;
    searchType: number;
    name: string;
    sort: number;
    status: boolean;
    src: UploadUserFile[];
    parentId?: string;
  };
  typeList: API.GetTypeSearchSettingList[];
};

const props = withDefaults(defineProps<Props>(), {
  modelValue: false,
});

const showWorkSearchType = computed(() => props.form.searchType === SearchType.Position);

const emit = defineEmits<{
  (e: 'update:modelValue', value: boolean): void;
  (e: 'update:form', value: Props['form']): void;
  (e: 'onConfirm'): void;
  (e: 'onCancel'): void;
}>();

const dialogForm = ref<FormInstance>();

const innerVisible = computed({
  get() {
    return props.modelValue;
  },
  set(val) {
    emit('update:modelValue', val);
  },
});

const innerForm = computed({
  get() {
    return props.form;
  },
  set(val) {
    emit('update:form', val);
  },
});

const rules = reactive<FormRules>({
  status: [{ required: true, message: '请选择状态', trigger: 'change' }],
  name: [{ required: true, message: '请输入名称', trigger: 'blur' }],
  sort: [{ required: true, message: '请输入排序', trigger: 'blur' }],
  parentId: [{ required: true, message: '请选择所属类别', trigger: 'change' }],
});

function onDialogClose() {
  if (!dialogForm.value) return;
  dialogForm.value.resetFields();
}

function handleConfirm() {
  if (!dialogForm.value) return;
  dialogForm.value.validate((valid) => {
    if (valid) {
      emit('onConfirm');
    } else {
      return;
    }
  });
}
</script>
